PolicySet

Struct PolicySet 

pub struct PolicySet {
    pub templates: LinkedHashMap<PolicyID, Policy>,
    pub static_policies: LinkedHashMap<PolicyID, Policy>,
    pub template_links: Vec<TemplateLink>,
}
Serde JSON structure for a policy set in the EST format

Fields

templates: LinkedHashMap<PolicyID, Policy>

The set of templates in a policy set

static_policies: LinkedHashMap<PolicyID, Policy>

The set of static policies in a policy set

template_links: Vec<TemplateLink>

The set of template links

Implementations

Source

impl PolicySet

pub fn get_policy(&self, id: &PolicyID) -> Option<Policy>

Get the static or template-linked policy with the given id. Returns an Option rather than a Result because it is expected to be used in cases where the policy set is guaranteed to be well-formed (e.g., after successful conversion to an ast::PolicySet)

pub fn get_template(&self, id: &PolicyID) -> Option<Policy>

Get the template with the given id. Returns an Option rather than a Result because it is expected to be used in cases where the policy set is guaranteed to be well-formed (e.g., after successful conversion to an ast::PolicySet)

pub fn max_expr_height(&self) -> Option<usize>

Return the largest Expr::height across every condition body in every static policy and template in this policy set. Returns None when there are no conditions.