macro_rules! assert_deep_eq {
( $self:expr , $other:expr ) => { ... };
}Expand description
Assert equality of Entities using structural equality with the deep_eq method.
macro_rules! assert_deep_eq {
( $self:expr , $other:expr ) => { ... };
}Assert equality of Entities using structural equality with the deep_eq method.