Struct cedar_policy_core::parser::cst::Policy
source · pub struct Policy {
pub annotations: Vec<Node<Option<Annotation>>>,
pub effect: Node<Option<Ident>>,
pub variables: Vec<Node<Option<VariableDef>>>,
pub conds: Vec<Node<Option<Cond>>>,
}Expand description
Policy statement, the main building block of the language
Fields
annotations: Vec<Node<Option<Annotation>>>Annotations
effect: Node<Option<Ident>>policy effect
variables: Vec<Node<Option<VariableDef>>>Variables
conds: Vec<Node<Option<Cond>>>Conditions
Implementations
sourceimpl Policy
impl Policy
sourcepub fn extract_scope(
&self,
errs: &mut ParseErrors,
) -> (Option<PrincipalConstraint>, Option<ActionConstraint>, Option<ResourceConstraint>)
pub fn extract_scope( &self, errs: &mut ParseErrors, ) -> (Option<PrincipalConstraint>, Option<ActionConstraint>, Option<ResourceConstraint>)
get the scope constraints from the cst::Policy
sourcepub fn get_ast_annotations(&self, errs: &mut ParseErrors) -> (bool, Annotations)
pub fn get_ast_annotations(&self, errs: &mut ParseErrors) -> (bool, Annotations)
Get the annotations on the cst::Policy as an ast::Annotations.
This returns a bool indicating whether conversion was successful for
all encountered annotations (true) or not (false), and also the
ast::Annotations object. Note that a partial ast::Annotations
object, containing only the valid annotations, may be returned even in
failure cases. In all failure cases, false will be returned and
errors will be added to errs.