pub fn parse_template(
id: Option<PolicyID>,
text: &str,
) -> Result<Template, ParseErrors>Expand description
Main function for parsing a template.
Will return an error if provided with a static policy.
If id is Some, then the resulting policy will have that id.
If the id is None, the parser will use “policy0”.