pub struct ExpectedErrorMessage<'a> { /* private fields */ }Available on crate feature
test-util only.Expand description
Describes the contents of an error message. Fields are based on the contents
of miette::Diagnostic.
Implementations
Sourceimpl<'a> ExpectedErrorMessage<'a>
impl<'a> ExpectedErrorMessage<'a>
Sourcepub fn matches(&self, error: &impl Diagnostic) -> bool
pub fn matches(&self, error: &impl Diagnostic) -> bool
Return a boolean indicating whether a given error matches this expected message.
(If you want to assert that it matches, use expect_err() instead,
for much better assertion-failure messages.)