pub struct ValidatorSchema { /* private fields */ }Expand description
Internal representation of the schema for use by the validator.
In this representation, all common types are fully expanded, and all entity type names are fully disambiguated (fully qualified).
Implementations
Sourceimpl ValidatorSchema
impl ValidatorSchema
Sourcepub fn to_json_schema(&self) -> Result<Fragment<RawName>, String>
pub fn to_json_schema(&self) -> Result<Fragment<RawName>, String>
Converts a ValidatorSchema into a json_schema::Fragment.
Roundtripping through this function gives a semantically equivalent
schema but will lose formatting, annotations, and common type
definitions. It will also inline the transitive closure of the entity
hierarchy for each entity type and action.
Sourcepub fn to_cedar_schema(&self) -> Result<String, String>
pub fn to_cedar_schema(&self) -> Result<String, String>
Converts a ValidatorSchema into a Cedar schema string.
This first converts to JSON schema format and then to Cedar syntax.
Sourceimpl ValidatorSchema
impl ValidatorSchema
Sourcepub fn new(
entity_types: impl IntoIterator<Item = ValidatorEntityType>,
action_ids: impl IntoIterator<Item = ValidatorActionId>,
) -> Self
pub fn new( entity_types: impl IntoIterator<Item = ValidatorEntityType>, action_ids: impl IntoIterator<Item = ValidatorActionId>, ) -> Self
Construct a new ValidatorSchema from a set of ValidatorEntityTypes and ValidatorActionIds.
The caller must ensure that there are no duplicate entity type names or action names in the input. Duplicates are silently collapsed (last entry wins).
Sourcepub fn common_types(&self) -> impl Iterator<Item = &LocatedCommonType>
Available on crate feature extended-schema only.
pub fn common_types(&self) -> impl Iterator<Item = &LocatedCommonType>
extended-schema only.Returns an iter of common types in the schema
Sourcepub fn namespaces(&self) -> impl Iterator<Item = &LocatedNamespace>
Available on crate feature extended-schema only.
pub fn namespaces(&self) -> impl Iterator<Item = &LocatedNamespace>
extended-schema only.Returns an iter of validator namespaces in the schema
Sourcepub fn principals(&self) -> impl Iterator<Item = &EntityType>
pub fn principals(&self) -> impl Iterator<Item = &EntityType>
Returns an iterator over every entity type that can be a principal for any action in this schema
Sourcepub fn resources(&self) -> impl Iterator<Item = &EntityType>
pub fn resources(&self) -> impl Iterator<Item = &EntityType>
Returns an iterator over every entity type that can be a resource for any action in this schema
Sourcepub fn principals_for_action(
&self,
action: &EntityUID,
) -> Option<impl Iterator<Item = &EntityType>>
pub fn principals_for_action( &self, action: &EntityUID, ) -> Option<impl Iterator<Item = &EntityType>>
Sourcepub fn resources_for_action(
&self,
action: &EntityUID,
) -> Option<impl Iterator<Item = &EntityType>>
pub fn resources_for_action( &self, action: &EntityUID, ) -> Option<impl Iterator<Item = &EntityType>>
Sourcepub fn actions_for_principal_and_resource<'a: 'b, 'b>(
&'a self,
principal_type: &'b EntityType,
resource_type: &'b EntityType,
) -> impl Iterator<Item = &'a EntityUID> + 'b
pub fn actions_for_principal_and_resource<'a: 'b, 'b>( &'a self, principal_type: &'b EntityType, resource_type: &'b EntityType, ) -> impl Iterator<Item = &'a EntityUID> + 'b
Returns an iterator over the actions that apply to this principal and
resource type, as specified by the appliesTo block for the action in
this schema.
Sourcepub fn unlinked_request_envs(
&self,
mode: ValidationMode,
) -> impl Iterator<Item = RequestEnv<'_>> + '_
pub fn unlinked_request_envs( &self, mode: ValidationMode, ) -> impl Iterator<Item = RequestEnv<'_>> + '_
Returns an iterator over every valid RequestEnv in the schema
Sourcepub fn ancestors<'a>(
&'a self,
ty: &'a EntityType,
) -> Option<impl Iterator<Item = &'a EntityType> + 'a>
pub fn ancestors<'a>( &'a self, ty: &'a EntityType, ) -> Option<impl Iterator<Item = &'a EntityType> + 'a>
Sourcepub fn action_groups(&self) -> impl Iterator<Item = &EntityUID>
pub fn action_groups(&self) -> impl Iterator<Item = &EntityUID>
Returns an iterator over all the action groups defined in this schema
Sourcepub fn actions(&self) -> impl Iterator<Item = &EntityUID>
pub fn actions(&self) -> impl Iterator<Item = &EntityUID>
Returns an iterator over all actions defined in this schema
Sourcepub fn empty() -> ValidatorSchema
pub fn empty() -> ValidatorSchema
Create a ValidatorSchema without any definitions (of entity types,
common types, or actions).
Sourcepub fn from_json_value(json: Value, extensions: &Extensions<'_>) -> Result<Self>
pub fn from_json_value(json: Value, extensions: &Extensions<'_>) -> Result<Self>
Construct a ValidatorSchema from a JSON value in the appropriate
shape.
Sourcepub fn from_json_str(json: &str, extensions: &Extensions<'_>) -> Result<Self>
pub fn from_json_str(json: &str, extensions: &Extensions<'_>) -> Result<Self>
Construct a ValidatorSchema from a string containing JSON in the
appropriate shape.
Sourcepub fn from_json_file(
file: impl Read,
extensions: &Extensions<'_>,
) -> Result<Self>
pub fn from_json_file( file: impl Read, extensions: &Extensions<'_>, ) -> Result<Self>
Construct a ValidatorSchema directly from a file containing JSON
in the appropriate shape.
Sourcepub fn from_cedarschema_file<'a>(
r: impl Read,
extensions: &'a Extensions<'a>,
) -> Result<(Self, impl Iterator<Item = SchemaWarning> + 'a), CedarSchemaError>
pub fn from_cedarschema_file<'a>( r: impl Read, extensions: &'a Extensions<'a>, ) -> Result<(Self, impl Iterator<Item = SchemaWarning> + 'a), CedarSchemaError>
Construct a ValidatorSchema directly from a file containing the
Cedar schema syntax.
Sourcepub fn from_cedarschema_str<'a>(
src: &str,
extensions: &Extensions<'a>,
) -> Result<(Self, impl Iterator<Item = SchemaWarning> + 'a), CedarSchemaError>
pub fn from_cedarschema_str<'a>( src: &str, extensions: &Extensions<'a>, ) -> Result<(Self, impl Iterator<Item = SchemaWarning> + 'a), CedarSchemaError>
Construct a ValidatorSchema from a string containing the Cedar
schema syntax.
Sourcepub fn from_schema_fragments(
fragments: impl IntoIterator<Item = ValidatorSchemaFragment<ConditionalName, ConditionalName>>,
extensions: &Extensions<'_>,
) -> Result<ValidatorSchema>
pub fn from_schema_fragments( fragments: impl IntoIterator<Item = ValidatorSchemaFragment<ConditionalName, ConditionalName>>, extensions: &Extensions<'_>, ) -> Result<ValidatorSchema>
Construct a ValidatorSchema from some number of ValidatorSchemaFragments.
Sourcepub fn get_action_id(&self, action_id: &EntityUID) -> Option<&ValidatorActionId>
pub fn get_action_id(&self, action_id: &EntityUID) -> Option<&ValidatorActionId>
Lookup the ValidatorActionId object in the schema with the given name.
Sourcepub fn get_entity_type<'a>(
&'a self,
entity_type_id: &EntityType,
) -> Option<&'a ValidatorEntityType>
pub fn get_entity_type<'a>( &'a self, entity_type_id: &EntityType, ) -> Option<&'a ValidatorEntityType>
Lookup the ValidatorEntityType object in the schema with the given name.
Sourcepub fn action_ids(&self) -> impl Iterator<Item = &ValidatorActionId>
pub fn action_ids(&self) -> impl Iterator<Item = &ValidatorActionId>
An iterator over the ValidatorActionIds in the schema.
Sourcepub fn entity_type_names(&self) -> impl Iterator<Item = &EntityType>
pub fn entity_type_names(&self) -> impl Iterator<Item = &EntityType>
An iterator over the entity type names in the schema.
Sourcepub fn entity_types(&self) -> impl Iterator<Item = &ValidatorEntityType>
pub fn entity_types(&self) -> impl Iterator<Item = &ValidatorEntityType>
An iterator over the ValidatorEntityTypes in the schema.
Sourcepub fn context_type(&self, action: &EntityUID) -> Option<&Type>
pub fn context_type(&self, action: &EntityUID) -> Option<&Type>
Get the Type of context expected for the given action.
This always returns a closed record type.
Returns None if the action is not in the schema.
Sourcepub fn action_entities(&self) -> Result<Entities, EntitiesError>
pub fn action_entities(&self) -> Result<Entities, EntitiesError>
Construct an Entity object for each action in the schema
Sourcepub fn try_validate(self) -> Result<Self, SchemaError>
pub fn try_validate(self) -> Result<Self, SchemaError>
Validate that a schema is well-formed according to the rules of the schema language. This is useful when the schema has been constructed directly from Rust code, without going through the JSON or Cedar schema syntax, and thus may not have been checked for well-formedness by the JSON or Cedar schema parsers.
More specifically, this checks the following:
- all entity types referenced are declared,
- all extension types in the schema are known extensions,
entity_typesdoes not declare actions andaction_idsdeclares only actions,- enum entities do not appear as descendants,
- RFC 70 shadowing rules are satisfied. Additionally, this recomputes the transitive closure computation for entity types and actions.
This does NOT check the following, which must be ensured before construction:
- duplicate entity type or action declarations (duplicates are silently collapsed
by
ValidatorSchema::newsince it collects into aHashMap; the protobuf conversion path detects duplicates before callingnew), - that context types are records
- common type resolution
Sourceimpl ValidatorSchema
impl ValidatorSchema
Sourcepub fn from_deprecated_json_value(
json: Value,
extensions: &Extensions<'_>,
) -> Result<Self, SchemaError>
pub fn from_deprecated_json_value( json: Value, extensions: &Extensions<'_>, ) -> Result<Self, SchemaError>
Construct a ValidatorSchema from a JSON value in the appropriate
shape.
Sourcepub fn from_deprecated_json_str(
json: &str,
extensions: &Extensions<'_>,
) -> Result<Self, SchemaError>
pub fn from_deprecated_json_str( json: &str, extensions: &Extensions<'_>, ) -> Result<Self, SchemaError>
Construct a ValidatorSchema from a string containing JSON in the
appropriate shape.
Sourcepub fn from_deprecated_json_file(
file: impl Read,
extensions: &Extensions<'_>,
) -> Result<Self, SchemaError>
pub fn from_deprecated_json_file( file: impl Read, extensions: &Extensions<'_>, ) -> Result<Self, SchemaError>
Construct a ValidatorSchema directly from a file containing JSON
in the appropriate shape.