pub struct LocatedNamespace {
pub name: SmolStr,
pub name_loc: Option<Loc>,
pub def_loc: Option<Loc>,
}Available on crate feature
extended-schema only.Expand description
Represents a namespace definition in the schema. This does not store the actual contents of the namespace and instead only stores where the namespace was defined. Namespaces are used to quality type definitions while constructing the schema. Once the schema is built, we only need to know about namespace definitions to support go-to source operations in the LSP.
Fields
name: SmolStrName of namespace
name_loc: Option<Loc>Namespace name source location if available
def_loc: Option<Loc>Namespace definition source location if available